/**
 * Documentation node kinds
 */
var NodeKind;
(function (NodeKind) {
    NodeKind[NodeKind["Table"] = 1] = "Table";
    NodeKind[NodeKind["TableRow"] = 2] = "TableRow";
    NodeKind[NodeKind["TableCell"] = 3] = "TableCell";
    NodeKind[NodeKind["Heading"] = 4] = "Heading";
    NodeKind[NodeKind["Paragraph"] = 5] = "Paragraph";
    NodeKind[NodeKind["Text"] = 6] = "Text";
    NodeKind[NodeKind["Bold"] = 7] = "Bold";
    NodeKind[NodeKind["Emphasis"] = 8] = "Emphasis";
    NodeKind[NodeKind["Link"] = 9] = "Link";
    NodeKind[NodeKind["Code"] = 10] = "Code";
    NodeKind[NodeKind["InlineCode"] = 11] = "InlineCode";
    NodeKind[NodeKind["Block"] = 12] = "Block";
    NodeKind[NodeKind["Collapsible"] = 13] = "Collapsible";
})(NodeKind || (NodeKind = {}));
/**
 * Node with children type guard predicate
 */
const isNodeWithChildren = (node) => {
    return (node.kind === NodeKind.Table ||
        node.kind === NodeKind.TableRow ||
        node.kind === NodeKind.TableCell ||
        node.kind === NodeKind.Heading ||
        node.kind === NodeKind.Paragraph ||
        node.kind === NodeKind.Bold ||
        node.kind === NodeKind.Emphasis ||
        node.kind === NodeKind.Link ||
        node.kind === NodeKind.Collapsible ||
        node.kind === NodeKind.Block);
};
/**
 * Node with value type guard predicate
 */
const isNodeWithValue = (node) => {
    return (node.kind === NodeKind.Text ||
        node.kind === NodeKind.InlineCode ||
        node.kind === NodeKind.Code);
};
/**
 * TableNode type guard predicate
 */
const isTableNode = (node) => {
    return node.kind === NodeKind.Table;
};
/**
 * TableRowNode type guard predicate
 */
const isTableRowNode = (node) => {
    return node.kind === NodeKind.TableRow;
};
/**
 * TableCellNode type guard predicate
 */
const isTableCellNode = (node) => {
    return node.kind === NodeKind.TableCell;
};
/**
 * HeadingNode type guard predicate
 */
const isHeadingNode = (node) => {
    return node.kind === NodeKind.Heading;
};
/**
 * ParagraphNode type guard predicate
 */
const isParagraphNode = (node) => {
    return node.kind === NodeKind.Paragraph;
};
/**
 * TextNode type guard predicate
 */
const isTextNode = (node) => {
    return node.kind === NodeKind.Text;
};
/**
 * BoldNode type guard predicate
 */
const isBoldNode = (node) => {
    return node.kind === NodeKind.Bold;
};
/**
 * EmphasisNode type guard predicate
 */
const isEmphasisNode = (node) => {
    return node.kind === NodeKind.Emphasis;
};
/**
 * LinkNode type guard predicate
 */
const isLinkNode = (node) => {
    return node.kind === NodeKind.Link;
};
/**
 * CodeNode type guard predicate
 */
const isCodeNode = (node) => {
    return node.kind === NodeKind.Code;
};
/**
 * InlineCodeNode type guard predicate
 */
const isInlineCodeNode = (node) => {
    return node.kind === NodeKind.InlineCode;
};
/**
 * BlockNode type guard predicate
 */
const isBlockNode = (node) => {
    return node.kind === NodeKind.Block;
};
/**
 * CollapsibleNode type guard predicate
 */
const isCollapsibleNode = (node) => {
    return node.kind === NodeKind.Collapsible;
};

export { NodeKind, isBlockNode, isBoldNode, isCodeNode, isCollapsibleNode, isEmphasisNode, isHeadingNode, isInlineCodeNode, isLinkNode, isNodeWithChildren, isNodeWithValue, isParagraphNode, isTableCellNode, isTableNode, isTableRowNode, isTextNode };
